@@ -29,6 +29,7 @@ from .adv_parsers.relay_switch import (
     process_worelay_switch_1,
     process_worelay_switch_1pm,
 )
+from .adv_parsers.remote import process_woremote
 from .const import SwitchbotModel
 from .models import SwitchBotAdvertisement
 
@@ -203,6 +204,12 @@ SUPPORTED_TYPES: dict[str, SwitchbotSupportedType] = {
         "func": process_worelay_switch_1,
         "manufacturer_id": 2409,
     },
+    "b": {
+        "modelName": SwitchbotModel.REMOTE,
+        "modelFriendlyName": "Remote",
+        "func": process_woremote,
+        "manufacturer_id": 89,
+    },
 }
 
 _SWITCHBOT_MODEL_TO_CHAR = {
